#!/bin/sh

cd $(dirname $0)
path=$1

if [ -d $path ]; then
  for file in $(ls $path); do
    if [ ! -d $path/$file ] && [ -x $path/$file ]; then
      #echo $path/$file
      $path/$file
    fi
  done
fi
